@@ -6,6 +6,12 @@ class ConsoleCmd(Enum):
     RECONNECT = 'reconnect'
     RESET = 'reset'
     POWER_ON = 'power_on'
-    POWER_OFF =  'power_off'
+    POWER_OFF = 'power_off'
+    CLEAR = "clear"
+
+    def _missing_(self, value:str):
+        if not isinstance(value, str):
+            return None
+        return value
 
 CONSOLE_COMMANDS = {cmd.value for cmd in ConsoleCmd}
